Module middleware
rustbasic_
translatable
0.0.2
Module middleware
Module Items
Statics
Functions
In crate rustbasic_
translatable
rustbasic_translatable
Module
middleware
Statics

CURRENT_
LOCALE
Functions

get_
locale
Retrieve the active request locale, falling back to default locale if not bound
translatable_
middleware
Axum Middleware to extract client’s preferred language and bind it to the request scope