Module middleware

Module middleware 

Statics

CURRENT_LOCALE

Functions

get_locale
Retrieve the active request locale, falling back to default locale if not bound
translatable_middleware
Axum Middleware to extract client’s preferred language and bind it to the request scope